import { AnyObjectSchema } from 'yup';
import { EnumType, ICrossFieldValidations, IFormFieldBase, IFormGroupBase, IValidationErrors } from './modelsCommon';
import { IFormParsed, IFormSettings } from './modelsParsed';
/**
 * @param formDataChildren - array of form fields
 * @param formSettings
 * @param acc - accumulator, used for recursion
 * @returns {[key: string]: any} - object with the initial values for the form
 * @description getInitialValues function returns an object with the initial values for the form
 * based on the initial values provided in the json schema
 */
export declare const getInitialValues: <T extends EnumType>(formDataChildren: (IFormFieldBase<T> | IFormGroupBase<T>)[], formSettings: IFormSettings<T>, acc?: any) => {
    [key: string]: any;
};
/**
 * @param schema - yup schema
 * @param fieldName - field name to get the rule value from
 * @param ruleName - rule name to get the value from
 * @returns {any} - rule value
 * @description getRuleValueFromSchema function returns the value of a rule from a yup schema
 * based on the field name and rule name. This value is needed for passing meta to translations.
 * @example getRuleValueFromSchema(schema, 'email', 'minLength') => 6
 */
export declare const getRuleValueFromSchema: (schema: AnyObjectSchema, fieldName: string, ruleName: string) => any;
/**
 * @param type - validation type
 * @param value - value to be validated
 * @param t - translation function(optional)
 * @param validationParam - validation param(meta) to be passed to the translation function(optional) or error object
 * @returns {any} - error object or function, or translated string
 * @description getFieldError function returns an error object or function, or translated string based on the validation type
 */
export declare const getFieldError: (type: string, value: string | null, t?: ((params: any, meta?: any) => void) | undefined, validationParam?: any) => any;
/**
 * @param validationObject
 * @param formValues - form values to be validated
 * @returns {IValidationErrors} - object with the validation errors
 * @description makeCrossFieldValidation function makes custom cross-field validation
 * and returns an object with the validation errors
 */
export declare const makeCrossFieldValidation: <T extends EnumType>(validationObject: ICrossFieldValidations<T>, formValues: { [key in T]: any; }) => IValidationErrors<T>;
/**
 * @param fieldName - field name
 * @param values - form values
 * @param errors - object with the validation errors
 * @returns {IValidationErrors} - object with the validation errors
 * @description validateDateRangeField function validates date range field
 * and returns an object with the validation errors
 */
export declare const validateDateRangeField: <T extends EnumType>(fieldName: T, values: any, errors?: IValidationErrors<T>) => IValidationErrors<T>;
/**
 * @param jsonSchema - json validation schema
 * @param t - translation function(optional)
 * @returns {AnyObjectSchema} - yup validation schema
 * @description buildYupSchema function builds a yup validation schema based on the json validation schema
 */
export declare const buildYupSchema: (jsonSchema: any, t?: ((params: any) => void) | undefined) => AnyObjectSchema;
/**
 * @param form {IForm} - form json schema
 * @param valuesToValidate {any} - form values to be validated
 * @param skipCrossField {boolean} - skip cross-field validation(optional)
 * @returns {Promise<unknown>} - object with the validation errors or error that has occurred during the validation
 * @description validateValues function validates the form values based on the json form object
 */
export declare const validateValues: <T extends EnumType>({ children, jsonSchema, formSettings }: IFormParsed<T>, valuesToValidate: { [key in T]: any; }, skipCrossField?: boolean) => Promise<unknown>;
